@@ -318,10 +318,6 @@ COMBINEABLE_ABILITIES: Set[AbilityId] = {
     AbilityId.HARVEST_GATHER,
     AbilityId.HARVEST_RETURN,
     AbilityId.EFFECT_REPAIR,
-    AbilityId.RALLY_BUILDING,
-    AbilityId.RALLY_UNITS,
-    AbilityId.RALLY_WORKERS,
-    AbilityId.RALLY_MORPHING_UNIT,
     AbilityId.LIFT,
     AbilityId.BURROWDOWN,
     AbilityId.BURROWUP,
